@@ -1,13 +1,13 @@
 package CatalystX::Resource::Controller::Resource;
 {
-    $CatalystX::Resource::Controller::Resource::VERSION = '0.001_003';
+    $CatalystX::Resource::Controller::Resource::VERSION = '0.001_004';
 }
 use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: Base Controller for Resources
 
-BEGIN { extends 'Catalyst::Controller'; }
+BEGIN { extends 'Catalyst::Controller::ActionRole'; }
 
 use MooseX::Types::Moose qw/ ArrayRef /;
 use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
@@ -30,6 +30,7 @@ __PACKAGE__->config(
             Edit
             /
     ],
+    action_roles => ['MatchRequestMethod'],
 );
 
 has 'model' => (
@@ -256,7 +257,7 @@ CatalystX::Resource::Controller::Resource - Base Controller for Resources
 
 =head1 VERSION
 
-version 0.001_003
+version 0.001_004
 
 =head1 ATTRIBUTES
 
